@@ -1,3 +1,5 @@
+import json
+import hashlib
 from metrics_layer.core.exceptions import QueryError
 from metrics_layer.core.parse.config import MetricsLayerConfiguration
 from collections import defaultdict
@@ -45,8 +47,12 @@ class MergedSQLQueryResolver(SingleSQLQueryResolver):
         self.derive_sub_queries()
 
         queries_to_join = {}
-        for join_hash in self.query_metrics.keys():
-            metrics = [f.id() for f in self.query_metrics[join_hash]]
+        join_hashes = list(self.query_metrics.keys())
+        for k in self.query_dimensions.keys():
+            if k not in join_hashes:
+                join_hashes.append(k)
+        for join_hash in join_hashes:
+            metrics = [f.id() for f in self.query_metrics.get(join_hash, [])]
             dimensions = [f.id() for f in self.query_dimensions.get(join_hash, [])]
 
             # Overwrite the limit arg because these are subqueries
@@ -70,7 +76,7 @@ class MergedSQLQueryResolver(SingleSQLQueryResolver):
             "query_dimensions": self.query_dimensions,
             "having": self.having,
             "queries_to_join": queries_to_join,
-            "join_hashes": list(sorted(self.query_metrics.keys())),
+            "join_hashes": list(sorted(join_hashes)),
             "query_type": resolver.query_type,
             "limit": self.limit,
             "project": self.project,
@@ -118,11 +124,11 @@ class MergedSQLQueryResolver(SingleSQLQueryResolver):
 
         self.query_metrics = self.deduplicate_fields(self.query_metrics)
 
-        dimension_mapping, canon_dates = self._canon_date_mapping()
+        dimension_mapping, canon_dates, used_join_hashes = self._canon_date_mapping()
 
         mappings = self.model.get_mappings()
         for key, map_to in mappings.items():
-            for other_join_hash, _ in self.query_metrics.items():
+            for other_join_hash in used_join_hashes:
                 if map_to["to_join_hash"] in other_join_hash:
                     map_to["from_join_hash"] = other_join_hash
                 dimension_mapping[key].append(deepcopy(map_to))
@@ -156,15 +162,26 @@ class MergedSQLQueryResolver(SingleSQLQueryResolver):
                                 "if you'd like to use this field in a merged result query."
                             )
                         for mapping_info in dimension_mapping[field_key]:
+                            ref_field = self.project.get_field(mapping_info["field"])
                             if mapping_info["from_join_hash"] in self.query_metrics:
-                                ref_field = self.project.get_field(mapping_info["field"])
                                 self.query_dimensions[mapping_info["from_join_hash"]].append(ref_field)
+                            else:
+                                canon_date = ref_field.canon_date.replace(".", "_")
+                                key = f"{canon_date}__{mapping_info['to_join_hash']}"
+                                self.query_dimensions[key].append(ref_field)
 
                 if not_in_metrics:
+                    field_key = f"{field.view.name}.{field.name}"
                     canon_date = field.canon_date.replace(".", "_")
                     key = f"{canon_date}__{join_group_hash}"
                     self.query_metrics[key] = []
                     self.query_dimensions[key].append(field)
+                    if field_key in dimension_mapping:
+                        for mapping_info in dimension_mapping[field_key]:
+                            ref_field = self.project.get_field(mapping_info["field"])
+                            canon_date = ref_field.canon_date.replace(".", "_")
+                            mapped_key = f"{canon_date}__{mapping_info['to_join_hash']}"
+                            self.query_dimensions[mapped_key].append(ref_field)
 
         self.query_dimensions = self.deduplicate_fields(self.query_dimensions)
 
@@ -173,9 +190,13 @@ class MergedSQLQueryResolver(SingleSQLQueryResolver):
             field = self.project.get_field(where["field"])
             dimension_group = field.dimension_group
             join_group_hash = self.project.join_graph.join_graph_hash(field.view.name)
-            for join_hash in self.query_metrics.keys():
+            added_filter = False
+            keys = list(self.query_metrics.keys()) + list(self.query_dimensions.keys())
+            unique_keys = sorted(list(set(keys)), key=lambda x: keys.index(x))
+            for join_hash in unique_keys:
                 if join_group_hash in join_hash:
                     self.query_where[join_hash].append(where)
+                    added_filter = True
                 else:
                     key = f"{field.view.name}.{field.name}"
                     for mapping_info in dimension_mapping[key]:
@@ -188,9 +209,25 @@ class MergedSQLQueryResolver(SingleSQLQueryResolver):
                             mapped_where = deepcopy(where)
                             mapped_where["field"] = ref_field.id()
                             self.query_where[join_hash].append(mapped_where)
+            if not added_filter:
+                # This handles the case where the where field is joined in and not in a mapping
+                for join_hash in self.query_metrics.keys():
+                    self.query_where[join_hash].append(where)
+
+        clean_wheres = defaultdict(list)
+        for k, v in self.query_where.items():
+            hashes, lookup = [], {}
+            for item in v:
+                h = self.hash_dict(item)
+                lookup[h] = item
+                hashes.append(h)
+
+            sorted_hashes = sorted(list(set(hashes)), key=lambda x: hashes.index(x))
+            clean_wheres[k] = [lookup[h] for h in sorted_hashes]
+        self.query_where = clean_wheres
 
     def _canon_date_mapping(self):
-        canon_dates = []
+        canon_dates, join_hashes = [], []
         dimension_mapping = defaultdict(list)
         for merged_metric in self.merged_metrics:
             for ref_field in merged_metric.referenced_fields(merged_metric.sql):
@@ -209,8 +246,9 @@ class MergedSQLQueryResolver(SingleSQLQueryResolver):
                     key = self._cte_name_from_parts(from_canon_date_name, join_group_hash)
                     canon_date_data = {"field": from_canon_date_name, "from_join_hash": key}
                     dimension_mapping[to_canon_date_name].append(canon_date_data)
+                    join_hashes.append(key)
 
-        return dimension_mapping, canon_dates
+        return dimension_mapping, canon_dates, list(set(join_hashes))
 
     @staticmethod
     def _cte_name_from_parts(field_id: str, join_group_hash: str):
@@ -221,3 +259,8 @@ class MergedSQLQueryResolver(SingleSQLQueryResolver):
     def deduplicate_fields(field_dict: dict):
         # Get rid of duplicates while keeping order to make joining work properly
         return {k: sorted(list(set(v)), key=lambda x: v.index(x)) for k, v in field_dict.items()}
+
+    @staticmethod
+    def hash_dict(input_dict: dict):
+        as_strings = {k: str(v) for k, v in input_dict.items()}
+        return hashlib.sha256(json.dumps(as_strings, sort_keys=True).encode("utf-8")).hexdigest()
